==> citrus-spring-4.0.2-sources.jar: org/citrusframework/model/config/core/DispatchingEndpointAdapterModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="mapping-key-extractor" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="mapping-strategy" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="fallback-adapter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "dispatching-endpoint-adapter")
public class DispatchingEndpointAdapterModel {

    @XmlAttribute(name = "id")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "mapping-key-extractor", required = true)
    protected String mappingKeyExtractor;
    @XmlAttribute(name = "mapping-strategy", required = true)
    protected String mappingStrategy;
    @XmlAttribute(name = "fallback-adapter")
    protected String fallbackAdapter;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der mappingKeyExtractor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMappingKeyExtractor() {
        return mappingKeyExtractor;
    }

    /**
     * Legt den Wert der mappingKeyExtractor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMappingKeyExtractor(String value) {
        this.mappingKeyExtractor = value;
    }

    /**
     * Ruft den Wert der mappingStrategy-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMappingStrategy() {
        return mappingStrategy;
    }

    /**
     * Legt den Wert der mappingStrategy-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMappingStrategy(String value) {
        this.mappingStrategy = value;
    }

    /**
     * Ruft den Wert der fallbackAdapter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFallbackAdapter() {
        return fallbackAdapter;
    }

    /**
     * Legt den Wert der fallbackAdapter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFallbackAdapter(String value) {
        this.fallbackAdapter = value;
    }

}

==> citrus-spring-4.1.1-sources.jar: org/citrusframework/model/config/core/DispatchingEndpointAdapterModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="mapping-key-extractor" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="mapping-strategy" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="fallback-adapter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "dispatching-endpoint-adapter")
public class DispatchingEndpointAdapterModel {

    @XmlAttribute(name = "id")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "mapping-key-extractor", required = true)
    protected String mappingKeyExtractor;
    @XmlAttribute(name = "mapping-strategy", required = true)
    protected String mappingStrategy;
    @XmlAttribute(name = "fallback-adapter")
    protected String fallbackAdapter;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der mappingKeyExtractor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMappingKeyExtractor() {
        return mappingKeyExtractor;
    }

    /**
     * Legt den Wert der mappingKeyExtractor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMappingKeyExtractor(String value) {
        this.mappingKeyExtractor = value;
    }

    /**
     * Ruft den Wert der mappingStrategy-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMappingStrategy() {
        return mappingStrategy;
    }

    /**
     * Legt den Wert der mappingStrategy-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMappingStrategy(String value) {
        this.mappingStrategy = value;
    }

    /**
     * Ruft den Wert der fallbackAdapter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFallbackAdapter() {
        return fallbackAdapter;
    }

    /**
     * Legt den Wert der fallbackAdapter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFallbackAdapter(String value) {
        this.fallbackAdapter = value;
    }

}
